# webp-cli-wrapper
An easy to use CLI wrapper for webp

## Convert to webp
```
convert_to_webp(source, output)

Optional parameters:
    quality: 0-100 defaults to 80
    method: 0-6 defaults to 4
    lossless: boolean defaults to false
    multithreading: defaults to true
```

## Convert from webp
```
convert_from_wepb(source, output)

Optional parameters:
    multithreading: defaults to true
```